Core Abstraction — Kivy v1.0.1-dev documentation

# Core Abstraction

This module defines the abstraction layers for our core providers and their implementations. For further information, please refer to Architectural Overview and the Core Providers and Input Providers section of the documentation.

In most cases, you shouldn’t directly use a library that’s already covered by the core abstraction. Always try to use our providers first. In case we are missing a feature or method, please let us know by opening a new Bug report instead of relying on your library.

> Note:
>   These are not widgets! These are just abstractions of the respective functionality. For example, you cannot add a core image to your window. You have to use the image widget class instead. If you’re really looking for widgets, please refer to `kivy.uix` instead.

- Audio
- Camera
- Clipboard
- OpenGL
- Image
- Spelling
- SVG
- Text
- Video
- Window